@@ -14,9 +14,7 @@ import (
 	olm "github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
 	mktconfig "github.com/operator-framework/operator-marketplace/pkg/apis/config/v1"
 	v1 "github.com/operator-framework/operator-marketplace/pkg/apis/operators/v1"
-	v2 "github.com/operator-framework/operator-marketplace/pkg/apis/operators/v2"
 	"github.com/operator-framework/operator-marketplace/pkg/defaults"
-	"github.com/operator-framework/operator-marketplace/pkg/metrics"
 	"github.com/operator-framework/operator-marketplace/pkg/operatorhub"
 	log "github.com/sirupsen/logrus"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
@@ -56,7 +54,7 @@ const (
 
 	upgradeableMessage = "Marketplace is upgradeable"
 
-	deprecatedAPIMessage = "The cluster has custom OperatorSource/CatalogSourceConfig, which are deprecated in future versions. Please visit this link for further deatils: https://docs.openshift.com/container-platform/4.4/release_notes/ocp-4-4-release-notes.html#ocp-4-4-marketplace-apis-deprecated"
+	deprecatedAPIMessage = "The cluster has custom OperatorSource, which is deprecated in future versions. Please visit this link for further details: https://docs.openshift.com/container-platform/4.4/release_notes/ocp-4-4-release-notes.html#ocp-4-4-marketplace-apis-deprecated"
 )
 
 type SyncSender interface {
@@ -65,7 +63,6 @@ type SyncSender interface {
 
 type Reporter interface {
 	StartReporting() <-chan struct{}
-	ReportMigration() error
 	SyncSender
 }
 
@@ -210,11 +207,6 @@ func (r *reporter) setRelatedObjects() {
 			Resource:  v1.OperatorSourceKind,
 			Namespace: r.namespace,
 		},
-		{
-			Group:     v2.SchemeGroupVersion.Group,
-			Resource:  v2.CatalogSourceConfigKind,
-			Namespace: r.namespace,
-		},
 		{
 			Group:     olm.GroupName,
 			Resource:  olm.CatalogSourceKind,
@@ -374,7 +366,7 @@ func NewReporter(cfg *rest.Config, mgr manager.Manager, namespace string, name s
 	if err != nil {
 		return nil, fmt.Errorf("failed to create config v1 client: %s", err.Error())
 	}
-	// Client for listing OperatorSources and CatalogSourceConfigs
+	// Client for listing OperatorSources
 	rawClient, err := client.New(cfg, client.Options{})
 	if err != nil {
 		return nil, fmt.Errorf("failed to create raw client: %s", err.Error())
@@ -403,18 +395,6 @@ func NewReporter(cfg *rest.Config, mgr manager.Manager, namespace string, name s
 	}, nil
 }
 
-// ReportMigration sets the clusterOperator status to signal that migration logic is in progress,
-// while upgrading from openshift 4.1.z to openshift 4.2.z
-func (r *reporter) ReportMigration() error {
-	conditionListBuilder := clusterStatusListBuilder()
-	conditionListBuilder(configv1.OperatorProgressing, configv1.ConditionTrue, fmt.Sprintf("Performing migration logic to progress towards release version: %s", r.version), "Upgrading")
-	msg := fmt.Sprintf("Determining status")
-	conditionListBuilder(configv1.OperatorAvailable, configv1.ConditionFalse, msg, "Upgrading")
-	conditionListBuilder(configv1.OperatorUpgradeable, configv1.ConditionFalse, msg, "Upgrading")
-	statusConditions := conditionListBuilder(configv1.OperatorDegraded, configv1.ConditionFalse, msg, "Upgrading")
-	return r.setStatus(statusConditions)
-}
-
 // StartReporting ensures that the cluster supports reporting ClusterOperator status
 // and returns a channel that reports if it is actively reporting.
 func (r *reporter) StartReporting() <-chan struct{} {
@@ -453,53 +433,31 @@ func (NoOpReporter) StartReporting() <-chan struct{} {
 	return ch
 }
 
-func (NoOpReporter) ReportMigration() error {
-	return nil
-}
-
-// CheckOperatorUpgradeablity checks for the presence of CatalogSourceConfigs,
-// and non default OperatorSources in the cluster. Since both the APIs are
-// scheduled to be deprecated/are already deprecated, checkOperatorUpgradeablity
-// returns false if it detects the presence of any CSC or non default Opsrc in
-// the cluster to indicate that the cluster is not upgradable to future versions.
+// CheckOperatorUpgradeablity checks for the presence of non default
+// OperatorSources in the cluster. Since the API is scheduled to be deprecated/is
+// already deprecated, checkOperatorUpgradeablity returns false if detects the presence
+// of any non default Opsrc in the cluster to indicate that the cluster is not upgradable
+// to future versions.
 func CheckOperatorUpgradeablity(kubeClient client.Client) (bool, error) {
-	cscCount, err := cscCount(kubeClient)
+	clusterHasOpsrc, err := isNonDefaultOpsrcPresent(kubeClient)
 	if err != nil {
 		return false, err
 	}
-
-	nonDefaultOpsrcCount, err := nonDefaultMarketplaceCRCount(kubeClient)
-	if err != nil {
-		return false, err
-	}
-
-	totalCount := cscCount + nonDefaultOpsrcCount
-
-	metrics.RegisterCustomResource(metrics.ResourceTypeOpsrc, float64(totalCount))
-	if totalCount > 0 {
+	if clusterHasOpsrc {
 		return false, nil
 	}
 	return true, nil
 }
 
-func cscCount(kubeClient client.Client) (int, error) {
-	cscs := &v2.CatalogSourceConfigList{}
-	if err := kubeClient.List(context.TODO(), &client.ListOptions{}, cscs); err != nil {
-		return 0, err
-	}
-	return len(cscs.Items), nil
-}
-
-func nonDefaultMarketplaceCRCount(kubeClient client.Client) (int, error) {
+func isNonDefaultOpsrcPresent(kubeClient client.Client) (bool, error) {
 	opsrcs := &v1.OperatorSourceList{}
-	nonDefaultOpsrcCount := 0
 	if err := kubeClient.List(context.TODO(), &client.ListOptions{}, opsrcs); err != nil {
-		return nonDefaultOpsrcCount, err
+		return false, err
 	}
 	for _, opsrc := range opsrcs.Items {
 		if !defaults.IsDefaultSource(opsrc.Name) {
-			nonDefaultOpsrcCount++
+			return true, nil
 		}
 	}
-	return nonDefaultOpsrcCount, nil
+	return false, nil
 }
